#ifndef cxxtls_stlstream_h_included_p
#define cxxtls_stlstream_h_included_p

#include <vector>
#include <list>
#include <deque>
#include <map>
#include <iostream>

///@file stlstream.h
///
///  This file defines some helper ostream&lt;&lt; methods to simplifying sending
///  things to std streams.  With it you can output vectors, lists, deques, and
///  pairs.
///

namespace cxxtls
{

template<class T>
std::ostream &operator<< (std::ostream &s, std::vector<T> const &me)
{
   typename std::vector<T>::const_iterator first = me.begin(), last = me.end();

   while(first != last)
   {
      s << *first++;

      if(first != last)
         s << ", ";
   }


   return s;
}

template<class T>
std::ostream &operator<< (std::ostream &s, std::list<T> const &me)
{
   typename std::list<T>::const_iterator first = me.begin(), last = me.end();

   while(first != last)
   {
      s << *first++;

      if(first != last)
         s << ", ";
   }


   return s;
}

template<class T>
std::ostream &operator<< (std::ostream &s, std::deque<T> const &me)
{
   typename std::deque<T>::const_iterator first = me.begin(), last = me.end();

   while(first != last)
   {
      s << *first++;

      if(first != last)
         s << ", ";
   }


   return s;
} // operator<< (deque)

template<class First, class Second>
std::ostream &operator<< (std::ostream &s, std::pair<First,Second> const &me)
{
  return s << '(' << me.first << ", " << me.second << ')';
}


} // namespace cxxtls

#endif
