#ifndef user_header_included
#define user_header_included


//
// Copyright 2002, Lowell Boggs Jr.
//
// This file or directory, containing source code for a computer program,
// is Copyrighted by Lowell Boggs, Jr.  987 Regency Drive, Lewisville
// TX (USA), 75067.  You may use, copy, modify, and distribute this
// source file without charge or obligation so long as you agree to
// the following:
//
//  1.  You must indemnify Lowell Boggs against any and all financial
//      obligations caused by its use, misuse, function, or malfunction.
//      Further, you acknowledge that there is no warranty of any kind,
//      whatsoever.
//
//  2.  You agree not to attempt to patent any portion of this original
//      work -- though you may attempt to patent your own extensions to
//      it if you so choose.
//
//  3.  You keep this copyright notice with the file and all copies
//      of the file and do not change it anyway except language translation.
//
// You are responsible for enforcing your own compliance with these
// conditions and may not use this source file if you cannot agree to the
// above terms and conditions.




///@file
///
///  This header file defines queries one might want to make about a
///  user.

#include <string>

namespace cxxtls
{

struct UserInfo
  //
  ///  Data about a given user and queries therefore.  If the queries
  ///  fail -- such as when a specified user id is invalid, the
  ///  name_ will be an emtpy string.  Otherwise, the data should be
  ///  valid.
  //
{
  std::string name_;      ///< user id name
  std::string password_;  ///< not in human readable form, may be empty
  std::string home_dir_;  ///< home directory
  std::string shell_;     ///< name of favorite command shell
  long        uid_;       ///< user id number
  long        gid_;       ///< group id number

  static UserInfo get();              ///< get this program's user id information
  static UserInfo get(long user);     ///< get info for a specified user
  static UserInfo get(char const *);  ///< get info for named user

  static UserInfo get(std::string const &s) ///  get info for named user
  {
    return get(s.c_str());
  }


};

} // namespace cxxtls

#endif
